How to start
============


Reading the documentation
-------------------------

You should probably start with the :ref:`examples` section.
This collection of examples will be progressively completed
to cover almost all the features of the library.

Some of the modules that are special or of particular interest
are described in the :ref:`uses` section.


Using the library
-----------------

Like most of all xarray-based projects, xoa not only provides
a :ref:`library <api>` but also :ref:`accessors <accessors>` for a convenient
access to part the fonctionalities.
The two uses are demonstrated in the pratical examples.
